@@ -85,7 +85,7 @@ class KarakeepAPI:
     """
 
     # Version reflects the client library version, updated by bumpver
-    VERSION: str = "1.3.1"
+    VERSION: str = "1.4.1"
 
     def __init__(
         self,
@@ -134,7 +134,7 @@ class KarakeepAPI:
 
         # Configure logger based on verbose setting
         log_level = "DEBUG" if self.verbose else "INFO"
-        logger.remove()  # Remove default handler
+        # logger.remove()  # Remove default handler
         if self.verbose:
             logger.add(
                 sys.stderr,
